package com.xinelu.manage.mapper.patientinfo;

import com.xinelu.manage.domain.patientinfo.PatientInfo;
import com.xinelu.manage.domain.patientinfoimport.PatientInfoImport;
import com.xinelu.manage.domain.residentinfo.ResidentInfo;
import com.xinelu.manage.dto.patientinfo.PatientInfoDto;
import com.xinelu.manage.vo.patientinfo.PatientBaseInfoVo;
import com.xinelu.manage.vo.patientinfo.PatientImportVo;
import com.xinelu.manage.vo.patientinfo.PatientInfoVo;
import com.xinelu.manage.vo.patientinfo.PatientNextTaskVo;
import org.apache.ibatis.annotations.Param;

import java.time.LocalDate;
import java.util.List;

/**
 * 患者信息Mapper接口
 *
 * @author haown
 * @date 2024-02-26
 */
public interface PatientInfoMapper {
    /**
     * 查询患者信息
     *
     * @param id 患者信息主键
     * @return 患者信息
     */
    PatientInfo selectPatientInfoById(Long id);

    /**
     * 查询患者信息
     *
     * @param id 主键id
     * @return 患者信息
     */
    PatientBaseInfoVo getPatientBaseInfo(Long id);

    /**
     * 查询患者信息列表
     *
     * @param patientInfo 患者信息
     * @return 患者信息集合
     */
    List<PatientInfo> selectPatientInfoList(PatientInfoDto patientInfo);

	/**
	 * @description 患者管理——患者档案列表
	 * @param patientInfo 患者信息查询传输对象
	 * @return 患者信息集合
	 * @Author haown
	 * @Date 2024-08-05 14:46
	*/
	List<PatientInfoVo> getPatientList(PatientInfoDto patientInfo);

	/**
	 * @description
	 * @param patientId 患者主键
	 * @return 下次任务
	 * @Author haown
	 * @Date 2024-08-06 14:54
	*/
	PatientNextTaskVo getPatientNextTask(Long patientId);

    /**
     * 新增患者信息
     *
     * @param patientInfo 患者信息
     * @return 结果
     */
    int insertPatientInfo(PatientInfo patientInfo);

    /**
     * 修改患者信息
     *
     * @param patientInfo 患者信息
     * @return 结果
     */
    int updatePatientInfoSelective(PatientInfo patientInfo);

	/**
	 * 修改患者信息
	 *
	 * @param patientInfo 患者信息
	 * @return 结果
	 */
	int updatePatientInfo(PatientInfo patientInfo);

    /**
     * 删除患者信息
     *
     * @param id 患者信息主键
     * @return 结果
     */
    int deletePatientInfoById(Long id);

    /**
     * 批量删除患者信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePatientInfoByIds(Long[] ids);

    /**
     * 根据openid查询被护理人信息
     *
     * @param openId 微信openId
     * @return 被护理人基本信息
     */
    ResidentInfo getPatientInfoByOpenId(String openId);

    /**
     * 根据创建时间查询患者数量
     *
     * @param firstDay 本月第一天
     * @param now      当前时间
     * @return int
     */
    int getPatientInfoCountByCreateTime(@Param("firstDay") LocalDate firstDay, @Param("now") LocalDate now, @Param("hospitalAgencyId")Long hospitalAgencyId);

    /**
     * 根据签约时间查询患者数量
     *
     * @param firstDay 本月第一天
     * @param now      当前时间
     * @return int
     */
    int selectPatientInfoCountBySignTime(@Param("firstDay") LocalDate firstDay, @Param("now") LocalDate now, @Param("hospitalAgencyId")Long hospitalAgencyId);

    /**
     * 已签约总数
     *
     * @return int
     */
    int selectPatientSignTotalCount(Long hospitalAgencyId);

    /**
     * 服务中患者总数
     *
     * @return int
     */
    int selectPatientSignServiceCount();

    /**
     * 批量当天查询患者信息
     *
     * @param list 集合
     * @return PatientInfo
     */
    List<PatientInfo> selectPatientInfoByPatientName(@Param("list") List<PatientInfoImport> list, @Param("nowDate") LocalDate nowDate);

    /**
     * 批量当月查询患者信息
     *
     * @param list 集合
     * @return PatientInfo
     */
    List<PatientImportVo> selectPatientInfoByTime(@Param("list") List<PatientInfoImport> list, @Param("startDate") String startDate, @Param("endDate") String endDate);

    /**
     * 新增患者信息
     *
     * @param patientInfo 患者信息
     * @return 结果
     */
    int insertPatientInfoList(List<PatientInfoImport> patientInfo);
}
